==> haskell-weigh-0.0.17-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.17
visibility:           public
id:                   weigh-0.0.17-219hK3vEP8254IxLIosZwA
key:                  weigh-0.0.17-219hK3vEP8254IxLIosZwA
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  9cd3e02e5e4523b1178c10789c3cd00f
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
library-dirs:         /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.17-219hK3vEP8254IxLIosZwA
depends:
    base-4.16.4.0 criterion-measurement-0.2.2.0-BtdbNr2VS3s1WYZvde6Fa3
    deepseq-1.4.6.1 ghc-9.2.8 mtl-2.2.2 process-1.6.16.0
    split-0.2.5-DTFSFkH8bnwnVGRxodGDM
    temporary-1.3-DbPriRXnwLpDQiIuk0AS91

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-weigh-0.0.17-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.17
visibility:           public
id:                   weigh-0.0.17-DQUFhNWjVK5GyZF8qGHJv4
key:                  weigh-0.0.17-DQUFhNWjVK5GyZF8qGHJv4
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  d4787e33c27bf3ad9dab5bd9a857f08f
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
library-dirs:         /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.17-DQUFhNWjVK5GyZF8qGHJv4
depends:
    base-4.16.4.0 criterion-measurement-0.2.2.0-Cwyxl920q6VAVHf1dGw7GG
    deepseq-1.4.6.1 ghc-9.2.8 mtl-2.2.2 process-1.6.16.0
    split-0.2.5-fPWkUXEXZHvXnPhPWCGf
    temporary-1.3-DlPEuuewvsKrIwgXPFoMU

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
